# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_REMOVE_ISLANDS_METADATA = Metadata(
    id="e985bca06df5a5d0c37e22c118468bf7cef4f5d3.boutiques",
    name="metric-remove-islands",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricRemoveIslandsParameters = typing.TypedDict('MetricRemoveIslandsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-remove-islands"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
MetricRemoveIslandsParametersTagged = typing.TypedDict('MetricRemoveIslandsParametersTagged', {
    "@type": typing.Literal["workbench/metric-remove-islands"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


class MetricRemoveIslandsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricRemoveIslandsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output ROI metric"""


def metric_remove_islands_params(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> MetricRemoveIslandsParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-remove-islands",
        "surface": surface,
        "metric_in": metric_in,
        "metric_out": metric_out,
    }
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def metric_remove_islands_cargs(
    params: MetricRemoveIslandsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-remove-islands")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def metric_remove_islands_outputs(
    params: MetricRemoveIslandsParameters,
    execution: Execution,
) -> MetricRemoveIslandsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricRemoveIslandsOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_remove_islands_execute(
    params: MetricRemoveIslandsParameters,
    runner: Runner | None = None,
) -> MetricRemoveIslandsOutputs:
    """
    metric-remove-islands
    
    Remove islands from an roi metric.
    
    Finds all connected areas in the ROI, and zeros out all but the largest one,
    in terms of surface area.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricRemoveIslandsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_REMOVE_ISLANDS_METADATA)
    params = execution.params(params)
    cargs = metric_remove_islands_cargs(params, execution)
    ret = metric_remove_islands_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_remove_islands(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricRemoveIslandsOutputs:
    """
    metric-remove-islands
    
    Remove islands from an roi metric.
    
    Finds all connected areas in the ROI, and zeros out all but the largest one,
    in terms of surface area.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use for neighbor information.
        metric_in: the input ROI metric.
        metric_out: the output ROI metric.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricRemoveIslandsOutputs`).
    """
    params = metric_remove_islands_params(
        surface=surface,
        metric_in=metric_in,
        metric_out=metric_out,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return metric_remove_islands_execute(params, runner)


__all__ = [
    "METRIC_REMOVE_ISLANDS_METADATA",
    "MetricRemoveIslandsOutputs",
    "metric_remove_islands",
    "metric_remove_islands_execute",
    "metric_remove_islands_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_MATH_METADATA = Metadata(
    id="a726aa1b4d69c5d8136af6cd6d227b61c7f03acf.boutiques",
    name="volume-math",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeMathVarParameters = typing.TypedDict('VolumeMathVarParameters', {
    "@type": typing.NotRequired[typing.Literal["var"]],
    "name": str,
    "volume": InputPathType,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_repeat": bool,
})
VolumeMathVarParametersTagged = typing.TypedDict('VolumeMathVarParametersTagged', {
    "@type": typing.Literal["var"],
    "name": str,
    "volume": InputPathType,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_repeat": bool,
})


VolumeMathParameters = typing.TypedDict('VolumeMathParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-math"]],
    "expression": str,
    "volume_out": str,
    "opt_fixnan_replace": typing.NotRequired[float | None],
    "var": typing.NotRequired[list[VolumeMathVarParameters] | None],
})
VolumeMathParametersTagged = typing.TypedDict('VolumeMathParametersTagged', {
    "@type": typing.Literal["workbench/volume-math"],
    "expression": str,
    "volume_out": str,
    "opt_fixnan_replace": typing.NotRequired[float | None],
    "var": typing.NotRequired[list[VolumeMathVarParameters] | None],
})


def volume_math_var_params(
    name: str,
    volume: InputPathType,
    opt_subvolume_subvol: str | None = None,
    opt_repeat: bool = False,
) -> VolumeMathVarParametersTagged:
    """
    Build parameters.
    
    Args:
        name: the name of the variable, as used in the expression.
        volume: the volume file to use as this variable.
        opt_subvolume_subvol: select a single subvolume: the subvolume number\
            or name.
        opt_repeat: reuse a single subvolume for each subvolume of calculation.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "var",
        "name": name,
        "volume": volume,
        "opt_repeat": opt_repeat,
    }
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_math_var_cargs(
    params: VolumeMathVarParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-var")
    cargs.append(params.get("name", None))
    cargs.append(execution.input_file(params.get("volume", None)))
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    if params.get("opt_repeat", False):
        cargs.append("-repeat")
    return cargs


class VolumeMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeMathParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_math_params(
    expression: str,
    volume_out: str,
    opt_fixnan_replace: float | None = None,
    var: list[VolumeMathVarParameters] | None = None,
) -> VolumeMathParametersTagged:
    """
    Build parameters.
    
    Args:
        expression: the expression to evaluate, in quotes.
        volume_out: the output volume.
        opt_fixnan_replace: replace NaN results with a value: value to replace\
            NaN with.
        var: a volume file to use as a variable.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-math",
        "expression": expression,
        "volume_out": volume_out,
    }
    if opt_fixnan_replace is not None:
        params["opt_fixnan_replace"] = opt_fixnan_replace
    if var is not None:
        params["var"] = var
    return params


def volume_math_cargs(
    params: VolumeMathParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-math")
    cargs.append(params.get("expression", None))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_fixnan_replace", None) is not None:
        cargs.extend([
            "-fixnan",
            str(params.get("opt_fixnan_replace", None))
        ])
    if params.get("var", None) is not None:
        cargs.extend([a for c in [volume_math_var_cargs(s, execution) for s in params.get("var", None)] for a in c])
    return cargs


def volume_math_outputs(
    params: VolumeMathParameters,
    execution: Execution,
) -> VolumeMathOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeMathOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_math_execute(
    params: VolumeMathParameters,
    runner: Runner | None = None,
) -> VolumeMathOutputs:
    """
    volume-math
    
    Evaluate expression on volume files.
    
    This command evaluates <expression> at each voxel independently. There must
    be at least one -var option (to get the volume space from), even if the
    <name> specified in it isn't used in <expression>. All volumes must have the
    same volume space. Filenames are not valid in <expression>, use a variable
    name and a -var option with matching <name> to specify an input file. If the
    -subvolume option is given to any -var option, only one subvolume is used
    from that file. If -repeat is specified, the file must either have only one
    subvolume, or have the -subvolume option specified. All files that don't use
    -repeat must have the same number of subvolumes requested to be used. The
    format of <expression> is as follows:
    
    Expressions consist of constants, variables, operators, parentheses, and
    functions, in infix notation, such as 'exp(-x + 3) * scale'. Variables are
    strings of any length, using the characters a-z, A-Z, 0-9, and _, but may
    not take the name of a named constant. Currently, there is only one named
    constant, PI. The operators are +, -, *, /, ^, >, <, >=, <=, ==, !=, !, &&,
    ||. These behave as in C, except that ^ is exponentiation, i.e. pow(x, y),
    and takes higher precedence than other binary operators (also, '-3^-4^-5'
    means '-(3^(-(4^-5)))'). The <=, >=, ==, and != operators are given a small
    amount of wiggle room, equal to one millionth of the smaller of the absolute
    values of the values being compared.
    
    Comparison and logical operators return 0 or 1, you can do masking with
    expressions like 'x * (mask > 0)'. For all logical operators, an input is
    considered true iff it is greater than 0. The expression '0 < x < 5' is not
    syntactically wrong, but it will NOT do what is desired, because it is
    evaluated left to right, i.e. '((0 < x) < 5)', which will always return 1,
    as both possible results of a comparison are less than 5. A warning is
    generated if an expression of this type is detected. Use something like 'x >
    0 && x < 5' to get the desired behavior.
    
    Whitespace between elements is ignored, ' sin ( 2 * x ) ' is equivalent to
    'sin(2*x)', but 's in(2*x)' is an error. Implied multiplication is not
    allowed, the expression '2x' will be parsed as a variable. Parentheses are
    (), do not use [] or {}. Functions require parentheses, the expression 'sin
    x' is an error.
    
    The following functions are supported:
    
    sin: 1 argument, the sine of the argument (units are radians)
    cos: 1 argument, the cosine of the argument (units are radians)
    tan: 1 argument, the tangent of the argument (units are radians)
    asin: 1 argument, the inverse of sine of the argument, in radians
    acos: 1 argument, the inverse of cosine of the argument, in radians
    atan: 1 argument, the inverse of tangent of the argument, in radians
    atan2: 2 arguments, atan2(y, x) returns the inverse of tangent of (y/x), in
    radians, determining quadrant by the sign of both arguments
    sinh: 1 argument, the hyperbolic sine of the argument
    cosh: 1 argument, the hyperbolic cosine of the argument
    tanh: 1 argument, the hyperbolic tangent of the argument
    asinh: 1 argument, the inverse hyperbolic sine of the argument
    acosh: 1 argument, the inverse hyperbolic cosine of the argument
    atanh: 1 argument, the inverse hyperbolic tangent of the argument
    sinc: 1 argument, sinc(0) = 1, sin(x) / x otherwise
    ln: 1 argument, the natural logarithm of the argument
    exp: 1 argument, the constant e raised to the power of the argument
    log: 1 argument, the base 10 logarithm of the argument
    log2: 1 argument, the base 2 logarithm of the argument
    sqrt: 1 argument, the square root of the argument
    abs: 1 argument, the absolute value of the argument
    floor: 1 argument, the largest integer not greater than the argument
    round: 1 argument, the nearest integer, with ties rounded away from zero
    ceil: 1 argument, the smallest integer not less than the argument
    min: 2 arguments, min(x, y) returns y if (x > y), x otherwise
    max: 2 arguments, max(x, y) returns y if (x < y), x otherwise
    mod: 2 arguments, mod(x, y) = x - y * floor(x / y), or 0 if y == 0
    clamp: 3 arguments, clamp(x, low, high) = min(max(x, low), high)
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_MATH_METADATA)
    params = execution.params(params)
    cargs = volume_math_cargs(params, execution)
    ret = volume_math_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_math(
    expression: str,
    volume_out: str,
    opt_fixnan_replace: float | None = None,
    var: list[VolumeMathVarParameters] | None = None,
    runner: Runner | None = None,
) -> VolumeMathOutputs:
    """
    volume-math
    
    Evaluate expression on volume files.
    
    This command evaluates <expression> at each voxel independently. There must
    be at least one -var option (to get the volume space from), even if the
    <name> specified in it isn't used in <expression>. All volumes must have the
    same volume space. Filenames are not valid in <expression>, use a variable
    name and a -var option with matching <name> to specify an input file. If the
    -subvolume option is given to any -var option, only one subvolume is used
    from that file. If -repeat is specified, the file must either have only one
    subvolume, or have the -subvolume option specified. All files that don't use
    -repeat must have the same number of subvolumes requested to be used. The
    format of <expression> is as follows:
    
    Expressions consist of constants, variables, operators, parentheses, and
    functions, in infix notation, such as 'exp(-x + 3) * scale'. Variables are
    strings of any length, using the characters a-z, A-Z, 0-9, and _, but may
    not take the name of a named constant. Currently, there is only one named
    constant, PI. The operators are +, -, *, /, ^, >, <, >=, <=, ==, !=, !, &&,
    ||. These behave as in C, except that ^ is exponentiation, i.e. pow(x, y),
    and takes higher precedence than other binary operators (also, '-3^-4^-5'
    means '-(3^(-(4^-5)))'). The <=, >=, ==, and != operators are given a small
    amount of wiggle room, equal to one millionth of the smaller of the absolute
    values of the values being compared.
    
    Comparison and logical operators return 0 or 1, you can do masking with
    expressions like 'x * (mask > 0)'. For all logical operators, an input is
    considered true iff it is greater than 0. The expression '0 < x < 5' is not
    syntactically wrong, but it will NOT do what is desired, because it is
    evaluated left to right, i.e. '((0 < x) < 5)', which will always return 1,
    as both possible results of a comparison are less than 5. A warning is
    generated if an expression of this type is detected. Use something like 'x >
    0 && x < 5' to get the desired behavior.
    
    Whitespace between elements is ignored, ' sin ( 2 * x ) ' is equivalent to
    'sin(2*x)', but 's in(2*x)' is an error. Implied multiplication is not
    allowed, the expression '2x' will be parsed as a variable. Parentheses are
    (), do not use [] or {}. Functions require parentheses, the expression 'sin
    x' is an error.
    
    The following functions are supported:
    
    sin: 1 argument, the sine of the argument (units are radians)
    cos: 1 argument, the cosine of the argument (units are radians)
    tan: 1 argument, the tangent of the argument (units are radians)
    asin: 1 argument, the inverse of sine of the argument, in radians
    acos: 1 argument, the inverse of cosine of the argument, in radians
    atan: 1 argument, the inverse of tangent of the argument, in radians
    atan2: 2 arguments, atan2(y, x) returns the inverse of tangent of (y/x), in
    radians, determining quadrant by the sign of both arguments
    sinh: 1 argument, the hyperbolic sine of the argument
    cosh: 1 argument, the hyperbolic cosine of the argument
    tanh: 1 argument, the hyperbolic tangent of the argument
    asinh: 1 argument, the inverse hyperbolic sine of the argument
    acosh: 1 argument, the inverse hyperbolic cosine of the argument
    atanh: 1 argument, the inverse hyperbolic tangent of the argument
    sinc: 1 argument, sinc(0) = 1, sin(x) / x otherwise
    ln: 1 argument, the natural logarithm of the argument
    exp: 1 argument, the constant e raised to the power of the argument
    log: 1 argument, the base 10 logarithm of the argument
    log2: 1 argument, the base 2 logarithm of the argument
    sqrt: 1 argument, the square root of the argument
    abs: 1 argument, the absolute value of the argument
    floor: 1 argument, the largest integer not greater than the argument
    round: 1 argument, the nearest integer, with ties rounded away from zero
    ceil: 1 argument, the smallest integer not less than the argument
    min: 2 arguments, min(x, y) returns y if (x > y), x otherwise
    max: 2 arguments, max(x, y) returns y if (x < y), x otherwise
    mod: 2 arguments, mod(x, y) = x - y * floor(x / y), or 0 if y == 0
    clamp: 3 arguments, clamp(x, low, high) = min(max(x, low), high)
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        expression: the expression to evaluate, in quotes.
        volume_out: the output volume.
        opt_fixnan_replace: replace NaN results with a value: value to replace\
            NaN with.
        var: a volume file to use as a variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeMathOutputs`).
    """
    params = volume_math_params(
        expression=expression,
        volume_out=volume_out,
        opt_fixnan_replace=opt_fixnan_replace,
        var=var,
    )
    return volume_math_execute(params, runner)


__all__ = [
    "VOLUME_MATH_METADATA",
    "VolumeMathOutputs",
    "volume_math",
    "volume_math_execute",
    "volume_math_params",
    "volume_math_var_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ROIS_FROM_EXTREMA_METADATA = Metadata(
    id="cb59a88fbbd13650bc2ec18aadb0883d2f6f58c8.boutiques",
    name="cifti-rois-from-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiRoisFromExtremaGaussianParameters = typing.TypedDict('CiftiRoisFromExtremaGaussianParameters', {
    "@type": typing.NotRequired[typing.Literal["gaussian"]],
    "surf_sigma": float,
    "vol_sigma": float,
})
CiftiRoisFromExtremaGaussianParametersTagged = typing.TypedDict('CiftiRoisFromExtremaGaussianParametersTagged', {
    "@type": typing.Literal["gaussian"],
    "surf_sigma": float,
    "vol_sigma": float,
})


CiftiRoisFromExtremaParameters = typing.TypedDict('CiftiRoisFromExtremaParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-rois-from-extrema"]],
    "cifti": InputPathType,
    "surf_limit": float,
    "vol_limit": float,
    "direction": str,
    "cifti_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
    "gaussian": typing.NotRequired[CiftiRoisFromExtremaGaussianParameters | None],
    "opt_overlap_logic_method": typing.NotRequired[str | None],
    "opt_merged_volume": bool,
})
CiftiRoisFromExtremaParametersTagged = typing.TypedDict('CiftiRoisFromExtremaParametersTagged', {
    "@type": typing.Literal["workbench/cifti-rois-from-extrema"],
    "cifti": InputPathType,
    "surf_limit": float,
    "vol_limit": float,
    "direction": str,
    "cifti_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
    "gaussian": typing.NotRequired[CiftiRoisFromExtremaGaussianParameters | None],
    "opt_overlap_logic_method": typing.NotRequired[str | None],
    "opt_merged_volume": bool,
})


def cifti_rois_from_extrema_gaussian_params(
    surf_sigma: float,
    vol_sigma: float,
) -> CiftiRoisFromExtremaGaussianParametersTagged:
    """
    Build parameters.
    
    Args:
        surf_sigma: the sigma for the surface gaussian kernel, in mm.
        vol_sigma: the sigma for the volume gaussian kernel, in mm.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "gaussian",
        "surf_sigma": surf_sigma,
        "vol_sigma": vol_sigma,
    }
    return params


def cifti_rois_from_extrema_gaussian_cargs(
    params: CiftiRoisFromExtremaGaussianParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-gaussian")
    cargs.append(str(params.get("surf_sigma", None)))
    cargs.append(str(params.get("vol_sigma", None)))
    return cargs


class CiftiRoisFromExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiRoisFromExtremaParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_rois_from_extrema_params(
    cifti: InputPathType,
    surf_limit: float,
    vol_limit: float,
    direction: str,
    cifti_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    gaussian: CiftiRoisFromExtremaGaussianParameters | None = None,
    opt_overlap_logic_method: str | None = None,
    opt_merged_volume: bool = False,
) -> CiftiRoisFromExtremaParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti.
        surf_limit: geodesic distance limit from vertex, in mm.
        vol_limit: euclidean distance limit from voxel center, in mm.
        direction: which dimension an extrema map is along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        gaussian: generate gaussian kernels instead of flat ROIs.
        opt_overlap_logic_method: how to handle overlapping ROIs, default\
            ALLOW: the method of resolving overlaps.
        opt_merged_volume: treat volume components as if they were a single\
            component.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-rois-from-extrema",
        "cifti": cifti,
        "surf_limit": surf_limit,
        "vol_limit": vol_limit,
        "direction": direction,
        "cifti_out": cifti_out,
        "opt_merged_volume": opt_merged_volume,
    }
    if opt_left_surface_surface is not None:
        params["opt_left_surface_surface"] = opt_left_surface_surface
    if opt_right_surface_surface is not None:
        params["opt_right_surface_surface"] = opt_right_surface_surface
    if opt_cerebellum_surface_surface is not None:
        params["opt_cerebellum_surface_surface"] = opt_cerebellum_surface_surface
    if gaussian is not None:
        params["gaussian"] = gaussian
    if opt_overlap_logic_method is not None:
        params["opt_overlap_logic_method"] = opt_overlap_logic_method
    return params


def cifti_rois_from_extrema_cargs(
    params: CiftiRoisFromExtremaParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-rois-from-extrema")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(str(params.get("surf_limit", None)))
    cargs.append(str(params.get("vol_limit", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_left_surface_surface", None) is not None:
        cargs.extend([
            "-left-surface",
            execution.input_file(params.get("opt_left_surface_surface", None))
        ])
    if params.get("opt_right_surface_surface", None) is not None:
        cargs.extend([
            "-right-surface",
            execution.input_file(params.get("opt_right_surface_surface", None))
        ])
    if params.get("opt_cerebellum_surface_surface", None) is not None:
        cargs.extend([
            "-cerebellum-surface",
            execution.input_file(params.get("opt_cerebellum_surface_surface", None))
        ])
    if params.get("gaussian", None) is not None:
        cargs.extend(cifti_rois_from_extrema_gaussian_cargs(params.get("gaussian", None), execution))
    if params.get("opt_overlap_logic_method", None) is not None:
        cargs.extend([
            "-overlap-logic",
            params.get("opt_overlap_logic_method", None)
        ])
    if params.get("opt_merged_volume", False):
        cargs.append("-merged-volume")
    return cargs


def cifti_rois_from_extrema_outputs(
    params: CiftiRoisFromExtremaParameters,
    execution: Execution,
) -> CiftiRoisFromExtremaOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiRoisFromExtremaOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_rois_from_extrema_execute(
    params: CiftiRoisFromExtremaParameters,
    runner: Runner | None = None,
) -> CiftiRoisFromExtremaOutputs:
    """
    cifti-rois-from-extrema
    
    Create cifti roi maps from extrema maps.
    
    For each nonzero value in each map, make a map with an ROI around that
    location. If the -gaussian option is specified, then normalized gaussian
    kernels are output instead of ROIs. The <method> argument to -overlap-logic
    must be one of ALLOW, CLOSEST, or EXCLUDE. ALLOW is the default, and means
    that ROIs are treated independently and may overlap. CLOSEST means that ROIs
    may not overlap, and that no ROI contains vertices that are closer to a
    different seed vertex. EXCLUDE means that ROIs may not overlap, and that any
    vertex within range of more than one ROI does not belong to any ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRoisFromExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ROIS_FROM_EXTREMA_METADATA)
    params = execution.params(params)
    cargs = cifti_rois_from_extrema_cargs(params, execution)
    ret = cifti_rois_from_extrema_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_rois_from_extrema(
    cifti: InputPathType,
    surf_limit: float,
    vol_limit: float,
    direction: str,
    cifti_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    gaussian: CiftiRoisFromExtremaGaussianParameters | None = None,
    opt_overlap_logic_method: str | None = None,
    opt_merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiRoisFromExtremaOutputs:
    """
    cifti-rois-from-extrema
    
    Create cifti roi maps from extrema maps.
    
    For each nonzero value in each map, make a map with an ROI around that
    location. If the -gaussian option is specified, then normalized gaussian
    kernels are output instead of ROIs. The <method> argument to -overlap-logic
    must be one of ALLOW, CLOSEST, or EXCLUDE. ALLOW is the default, and means
    that ROIs are treated independently and may overlap. CLOSEST means that ROIs
    may not overlap, and that no ROI contains vertices that are closer to a
    different seed vertex. EXCLUDE means that ROIs may not overlap, and that any
    vertex within range of more than one ROI does not belong to any ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti.
        surf_limit: geodesic distance limit from vertex, in mm.
        vol_limit: euclidean distance limit from voxel center, in mm.
        direction: which dimension an extrema map is along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        gaussian: generate gaussian kernels instead of flat ROIs.
        opt_overlap_logic_method: how to handle overlapping ROIs, default\
            ALLOW: the method of resolving overlaps.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRoisFromExtremaOutputs`).
    """
    params = cifti_rois_from_extrema_params(
        cifti=cifti,
        surf_limit=surf_limit,
        vol_limit=vol_limit,
        direction=direction,
        cifti_out=cifti_out,
        opt_left_surface_surface=opt_left_surface_surface,
        opt_right_surface_surface=opt_right_surface_surface,
        opt_cerebellum_surface_surface=opt_cerebellum_surface_surface,
        gaussian=gaussian,
        opt_overlap_logic_method=opt_overlap_logic_method,
        opt_merged_volume=opt_merged_volume,
    )
    return cifti_rois_from_extrema_execute(params, runner)


__all__ = [
    "CIFTI_ROIS_FROM_EXTREMA_METADATA",
    "CiftiRoisFromExtremaOutputs",
    "cifti_rois_from_extrema",
    "cifti_rois_from_extrema_execute",
    "cifti_rois_from_extrema_gaussian_params",
    "cifti_rois_from_extrema_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ZIP_SCENE_FILE_METADATA = Metadata(
    id="85d5fb1af707c34c6db735360187816616cc1dda.boutiques",
    name="zip-scene-file",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ZipSceneFileParameters = typing.TypedDict('ZipSceneFileParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/zip-scene-file"]],
    "scene_file": str,
    "extract_folder": str,
    "zip_file": str,
    "opt_base_dir_directory": typing.NotRequired[str | None],
    "opt_skip_missing": bool,
    "opt_write_scene_file": bool,
})
ZipSceneFileParametersTagged = typing.TypedDict('ZipSceneFileParametersTagged', {
    "@type": typing.Literal["workbench/zip-scene-file"],
    "scene_file": str,
    "extract_folder": str,
    "zip_file": str,
    "opt_base_dir_directory": typing.NotRequired[str | None],
    "opt_skip_missing": bool,
    "opt_write_scene_file": bool,
})


class ZipSceneFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ZipSceneFileParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def zip_scene_file_params(
    scene_file: str,
    extract_folder: str,
    zip_file: str,
    opt_base_dir_directory: str | None = None,
    opt_skip_missing: bool = False,
    opt_write_scene_file: bool = False,
) -> ZipSceneFileParametersTagged:
    """
    Build parameters.
    
    Args:
        scene_file: the scene file to make the zip file from.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        opt_base_dir_directory: specify a directory that all data files are\
            somewhere within, this will become the root of the zipfile's directory\
            structure: the directory.
        opt_skip_missing: any missing files will generate only warnings, and\
            the zip file will be created anyway.
        opt_write_scene_file: rewrite the scene file before zipping, to store a\
            new base path or fix extra '..'s in paths that might break.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/zip-scene-file",
        "scene_file": scene_file,
        "extract_folder": extract_folder,
        "zip_file": zip_file,
        "opt_skip_missing": opt_skip_missing,
        "opt_write_scene_file": opt_write_scene_file,
    }
    if opt_base_dir_directory is not None:
        params["opt_base_dir_directory"] = opt_base_dir_directory
    return params


def zip_scene_file_cargs(
    params: ZipSceneFileParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-zip-scene-file")
    cargs.append(params.get("scene_file", None))
    cargs.append(params.get("extract_folder", None))
    cargs.append(params.get("zip_file", None))
    if params.get("opt_base_dir_directory", None) is not None:
        cargs.extend([
            "-base-dir",
            params.get("opt_base_dir_directory", None)
        ])
    if params.get("opt_skip_missing", False):
        cargs.append("-skip-missing")
    if params.get("opt_write_scene_file", False):
        cargs.append("-write-scene-file")
    return cargs


def zip_scene_file_outputs(
    params: ZipSceneFileParameters,
    execution: Execution,
) -> ZipSceneFileOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ZipSceneFileOutputs(
        root=execution.output_file("."),
    )
    return ret


def zip_scene_file_execute(
    params: ZipSceneFileParameters,
    runner: Runner | None = None,
) -> ZipSceneFileOutputs:
    """
    zip-scene-file
    
    Zip a scene file and its data files.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the base directory will be automatically set to the lowest level
    directory containing all files. The scene file must contain only relative
    paths, and no data files may be outside the base directory.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSceneFileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZIP_SCENE_FILE_METADATA)
    params = execution.params(params)
    cargs = zip_scene_file_cargs(params, execution)
    ret = zip_scene_file_outputs(params, execution)
    execution.run(cargs)
    return ret


def zip_scene_file(
    scene_file: str,
    extract_folder: str,
    zip_file: str,
    opt_base_dir_directory: str | None = None,
    opt_skip_missing: bool = False,
    opt_write_scene_file: bool = False,
    runner: Runner | None = None,
) -> ZipSceneFileOutputs:
    """
    zip-scene-file
    
    Zip a scene file and its data files.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the base directory will be automatically set to the lowest level
    directory containing all files. The scene file must contain only relative
    paths, and no data files may be outside the base directory.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        scene_file: the scene file to make the zip file from.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        opt_base_dir_directory: specify a directory that all data files are\
            somewhere within, this will become the root of the zipfile's directory\
            structure: the directory.
        opt_skip_missing: any missing files will generate only warnings, and\
            the zip file will be created anyway.
        opt_write_scene_file: rewrite the scene file before zipping, to store a\
            new base path or fix extra '..'s in paths that might break.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSceneFileOutputs`).
    """
    params = zip_scene_file_params(
        scene_file=scene_file,
        extract_folder=extract_folder,
        zip_file=zip_file,
        opt_base_dir_directory=opt_base_dir_directory,
        opt_skip_missing=opt_skip_missing,
        opt_write_scene_file=opt_write_scene_file,
    )
    return zip_scene_file_execute(params, runner)


__all__ = [
    "ZIP_SCENE_FILE_METADATA",
    "ZipSceneFileOutputs",
    "zip_scene_file",
    "zip_scene_file_execute",
    "zip_scene_file_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

GIFTI_ALL_LABELS_TO_ROIS_METADATA = Metadata(
    id="c85f9eb68f2374346bb8a16f7c99697fee1153fa.boutiques",
    name="gifti-all-labels-to-rois",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


GiftiAllLabelsToRoisParameters = typing.TypedDict('GiftiAllLabelsToRoisParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/gifti-all-labels-to-rois"]],
    "label_in": InputPathType,
    "map": str,
    "metric_out": str,
})
GiftiAllLabelsToRoisParametersTagged = typing.TypedDict('GiftiAllLabelsToRoisParametersTagged', {
    "@type": typing.Literal["workbench/gifti-all-labels-to-rois"],
    "label_in": InputPathType,
    "map": str,
    "metric_out": str,
})


class GiftiAllLabelsToRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `GiftiAllLabelsToRoisParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def gifti_all_labels_to_rois_params(
    label_in: InputPathType,
    map_: str,
    metric_out: str,
) -> GiftiAllLabelsToRoisParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input gifti label file.
        map_: the number or name of the label map to use.
        metric_out: the output metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/gifti-all-labels-to-rois",
        "label_in": label_in,
        "map": map_,
        "metric_out": metric_out,
    }
    return params


def gifti_all_labels_to_rois_cargs(
    params: GiftiAllLabelsToRoisParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-all-labels-to-rois")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("map", None))
    cargs.append(params.get("metric_out", None))
    return cargs


def gifti_all_labels_to_rois_outputs(
    params: GiftiAllLabelsToRoisParameters,
    execution: Execution,
) -> GiftiAllLabelsToRoisOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = GiftiAllLabelsToRoisOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def gifti_all_labels_to_rois_execute(
    params: GiftiAllLabelsToRoisParameters,
    runner: Runner | None = None,
) -> GiftiAllLabelsToRoisOutputs:
    """
    gifti-all-labels-to-rois
    
    Make rois from all labels in a gifti column.
    
    The output metric file has a column for each label in the specified input
    map, other than the ??? label, each of which contains an ROI of all vertices
    that are set to the corresponding label.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiAllLabelsToRoisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_ALL_LABELS_TO_ROIS_METADATA)
    params = execution.params(params)
    cargs = gifti_all_labels_to_rois_cargs(params, execution)
    ret = gifti_all_labels_to_rois_outputs(params, execution)
    execution.run(cargs)
    return ret


def gifti_all_labels_to_rois(
    label_in: InputPathType,
    map_: str,
    metric_out: str,
    runner: Runner | None = None,
) -> GiftiAllLabelsToRoisOutputs:
    """
    gifti-all-labels-to-rois
    
    Make rois from all labels in a gifti column.
    
    The output metric file has a column for each label in the specified input
    map, other than the ??? label, each of which contains an ROI of all vertices
    that are set to the corresponding label.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input gifti label file.
        map_: the number or name of the label map to use.
        metric_out: the output metric file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiAllLabelsToRoisOutputs`).
    """
    params = gifti_all_labels_to_rois_params(
        label_in=label_in,
        map_=map_,
        metric_out=metric_out,
    )
    return gifti_all_labels_to_rois_execute(params, runner)


__all__ = [
    "GIFTI_ALL_LABELS_TO_ROIS_METADATA",
    "GiftiAllLabelsToRoisOutputs",
    "gifti_all_labels_to_rois",
    "gifti_all_labels_to_rois_execute",
    "gifti_all_labels_to_rois_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_AFFINE_METADATA = Metadata(
    id="4cd37f69e7dc378d87a51d9e406bdba4fef416e6.boutiques",
    name="convert-affine",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ConvertAffineFromWorldParameters = typing.TypedDict('ConvertAffineFromWorldParameters', {
    "@type": typing.NotRequired[typing.Literal["from_world"]],
    "input": str,
    "opt_inverse": bool,
})
ConvertAffineFromWorldParametersTagged = typing.TypedDict('ConvertAffineFromWorldParametersTagged', {
    "@type": typing.Literal["from_world"],
    "input": str,
    "opt_inverse": bool,
})


ConvertAffineFromFlirtParameters = typing.TypedDict('ConvertAffineFromFlirtParameters', {
    "@type": typing.NotRequired[typing.Literal["from_flirt"]],
    "input": str,
    "source_volume": str,
    "target_volume": str,
})
ConvertAffineFromFlirtParametersTagged = typing.TypedDict('ConvertAffineFromFlirtParametersTagged', {
    "@type": typing.Literal["from_flirt"],
    "input": str,
    "source_volume": str,
    "target_volume": str,
})


ConvertAffineToWorldParameters = typing.TypedDict('ConvertAffineToWorldParameters', {
    "@type": typing.NotRequired[typing.Literal["to_world"]],
    "output": str,
    "opt_inverse": bool,
})
ConvertAffineToWorldParametersTagged = typing.TypedDict('ConvertAffineToWorldParametersTagged', {
    "@type": typing.Literal["to_world"],
    "output": str,
    "opt_inverse": bool,
})


ConvertAffineToFlirtParameters = typing.TypedDict('ConvertAffineToFlirtParameters', {
    "@type": typing.NotRequired[typing.Literal["to_flirt"]],
    "output": str,
    "source_volume": str,
    "target_volume": str,
})
ConvertAffineToFlirtParametersTagged = typing.TypedDict('ConvertAffineToFlirtParametersTagged', {
    "@type": typing.Literal["to_flirt"],
    "output": str,
    "source_volume": str,
    "target_volume": str,
})


ConvertAffineParameters = typing.TypedDict('ConvertAffineParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/convert-affine"]],
    "from_world": typing.NotRequired[ConvertAffineFromWorldParameters | None],
    "opt_from_itk_input": typing.NotRequired[str | None],
    "from_flirt": typing.NotRequired[ConvertAffineFromFlirtParameters | None],
    "to_world": typing.NotRequired[ConvertAffineToWorldParameters | None],
    "opt_to_itk_output": typing.NotRequired[str | None],
    "to_flirt": typing.NotRequired[list[ConvertAffineToFlirtParameters] | None],
})
ConvertAffineParametersTagged = typing.TypedDict('ConvertAffineParametersTagged', {
    "@type": typing.Literal["workbench/convert-affine"],
    "from_world": typing.NotRequired[ConvertAffineFromWorldParameters | None],
    "opt_from_itk_input": typing.NotRequired[str | None],
    "from_flirt": typing.NotRequired[ConvertAffineFromFlirtParameters | None],
    "to_world": typing.NotRequired[ConvertAffineToWorldParameters | None],
    "opt_to_itk_output": typing.NotRequired[str | None],
    "to_flirt": typing.NotRequired[list[ConvertAffineToFlirtParameters] | None],
})


def convert_affine_from_world_params(
    input_: str,
    opt_inverse: bool = False,
) -> ConvertAffineFromWorldParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: the input affine.
        opt_inverse: for files that use 'target to source' convention.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_world",
        "input": input_,
        "opt_inverse": opt_inverse,
    }
    return params


def convert_affine_from_world_cargs(
    params: ConvertAffineFromWorldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-world")
    cargs.append(params.get("input", None))
    if params.get("opt_inverse", False):
        cargs.append("-inverse")
    return cargs


def convert_affine_from_flirt_params(
    input_: str,
    source_volume: str,
    target_volume: str,
) -> ConvertAffineFromFlirtParametersTagged:
    """
    Build parameters.
    
    Args:
        input_: the input affine.
        source_volume: the source volume used when generating the input affine.
        target_volume: the target volume used when generating the input affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_flirt",
        "input": input_,
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def convert_affine_from_flirt_cargs(
    params: ConvertAffineFromFlirtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-flirt")
    cargs.append(params.get("input", None))
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


def convert_affine_to_world_params(
    output: str,
    opt_inverse: bool = False,
) -> ConvertAffineToWorldParametersTagged:
    """
    Build parameters.
    
    Args:
        output: output - the output affine.
        opt_inverse: write file using 'target to source' convention.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_world",
        "output": output,
        "opt_inverse": opt_inverse,
    }
    return params


def convert_affine_to_world_cargs(
    params: ConvertAffineToWorldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-world")
    cargs.append(params.get("output", None))
    if params.get("opt_inverse", False):
        cargs.append("-inverse")
    return cargs


def convert_affine_to_flirt_params(
    output: str,
    source_volume: str,
    target_volume: str,
) -> ConvertAffineToFlirtParametersTagged:
    """
    Build parameters.
    
    Args:
        output: output - the output affine.
        source_volume: the volume you want to apply the transform to.
        target_volume: the target space you want the transformed volume to\
            match.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_flirt",
        "output": output,
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def convert_affine_to_flirt_cargs(
    params: ConvertAffineToFlirtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-flirt")
    cargs.append(params.get("output", None))
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


class ConvertAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertAffineParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_affine_params(
    from_world: ConvertAffineFromWorldParameters | None = None,
    opt_from_itk_input: str | None = None,
    from_flirt: ConvertAffineFromFlirtParameters | None = None,
    to_world: ConvertAffineToWorldParameters | None = None,
    opt_to_itk_output: str | None = None,
    to_flirt: list[ConvertAffineToFlirtParameters] | None = None,
) -> ConvertAffineParametersTagged:
    """
    Build parameters.
    
    Args:
        from_world: input is a NIFTI 'world' affine.
        opt_from_itk_input: input is an ITK matrix: the input affine.
        from_flirt: input is a flirt matrix.
        to_world: write output as a NIFTI 'world' affine.
        opt_to_itk_output: write output as an ITK affine: output - the output\
            affine.
        to_flirt: write output as a flirt matrix.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/convert-affine",
    }
    if from_world is not None:
        params["from_world"] = from_world
    if opt_from_itk_input is not None:
        params["opt_from_itk_input"] = opt_from_itk_input
    if from_flirt is not None:
        params["from_flirt"] = from_flirt
    if to_world is not None:
        params["to_world"] = to_world
    if opt_to_itk_output is not None:
        params["opt_to_itk_output"] = opt_to_itk_output
    if to_flirt is not None:
        params["to_flirt"] = to_flirt
    return params


def convert_affine_cargs(
    params: ConvertAffineParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-affine")
    if params.get("from_world", None) is not None:
        cargs.extend(convert_affine_from_world_cargs(params.get("from_world", None), execution))
    if params.get("opt_from_itk_input", None) is not None:
        cargs.extend([
            "-from-itk",
            params.get("opt_from_itk_input", None)
        ])
    if params.get("from_flirt", None) is not None:
        cargs.extend(convert_affine_from_flirt_cargs(params.get("from_flirt", None), execution))
    if params.get("to_world", None) is not None:
        cargs.extend(convert_affine_to_world_cargs(params.get("to_world", None), execution))
    if params.get("opt_to_itk_output", None) is not None:
        cargs.extend([
            "-to-itk",
            params.get("opt_to_itk_output", None)
        ])
    if params.get("to_flirt", None) is not None:
        cargs.extend([a for c in [convert_affine_to_flirt_cargs(s, execution) for s in params.get("to_flirt", None)] for a in c])
    return cargs


def convert_affine_outputs(
    params: ConvertAffineParameters,
    execution: Execution,
) -> ConvertAffineOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertAffineOutputs(
        root=execution.output_file("."),
    )
    return ret


def convert_affine_execute(
    params: ConvertAffineParameters,
    runner: Runner | None = None,
) -> ConvertAffineOutputs:
    """
    convert-affine
    
    Convert an affine file between conventions.
    
    NIFTI world matrices can be used directly on mm coordinates via matrix
    multiplication, they use the NIFTI coordinate system, that is, positive X is
    right, positive Y is anterior, and positive Z is superior. Note that
    wb_command assumes that world matrices transform source coordinates to
    target coordinates, while other tools may use affines that transform target
    coordinates to source coordinates.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-flirt may be specified more than once.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_AFFINE_METADATA)
    params = execution.params(params)
    cargs = convert_affine_cargs(params, execution)
    ret = convert_affine_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_affine(
    from_world: ConvertAffineFromWorldParameters | None = None,
    opt_from_itk_input: str | None = None,
    from_flirt: ConvertAffineFromFlirtParameters | None = None,
    to_world: ConvertAffineToWorldParameters | None = None,
    opt_to_itk_output: str | None = None,
    to_flirt: list[ConvertAffineToFlirtParameters] | None = None,
    runner: Runner | None = None,
) -> ConvertAffineOutputs:
    """
    convert-affine
    
    Convert an affine file between conventions.
    
    NIFTI world matrices can be used directly on mm coordinates via matrix
    multiplication, they use the NIFTI coordinate system, that is, positive X is
    right, positive Y is anterior, and positive Z is superior. Note that
    wb_command assumes that world matrices transform source coordinates to
    target coordinates, while other tools may use affines that transform target
    coordinates to source coordinates.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-flirt may be specified more than once.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        from_world: input is a NIFTI 'world' affine.
        opt_from_itk_input: input is an ITK matrix: the input affine.
        from_flirt: input is a flirt matrix.
        to_world: write output as a NIFTI 'world' affine.
        opt_to_itk_output: write output as an ITK affine: output - the output\
            affine.
        to_flirt: write output as a flirt matrix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertAffineOutputs`).
    """
    params = convert_affine_params(
        from_world=from_world,
        opt_from_itk_input=opt_from_itk_input,
        from_flirt=from_flirt,
        to_world=to_world,
        opt_to_itk_output=opt_to_itk_output,
        to_flirt=to_flirt,
    )
    return convert_affine_execute(params, runner)


__all__ = [
    "CONVERT_AFFINE_METADATA",
    "ConvertAffineOutputs",
    "convert_affine",
    "convert_affine_execute",
    "convert_affine_from_flirt_params",
    "convert_affine_from_world_params",
    "convert_affine_params",
    "convert_affine_to_flirt_params",
    "convert_affine_to_world_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_STATS_METADATA = Metadata(
    id="852ba0d83f7d875e846bb1d014e2f98430b0a0ae.boutiques",
    name="cifti-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiStatsRoiParameters = typing.TypedDict('CiftiStatsRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["roi"]],
    "roi_cifti": InputPathType,
    "opt_match_maps": bool,
})
CiftiStatsRoiParametersTagged = typing.TypedDict('CiftiStatsRoiParametersTagged', {
    "@type": typing.Literal["roi"],
    "roi_cifti": InputPathType,
    "opt_match_maps": bool,
})


CiftiStatsParameters = typing.TypedDict('CiftiStatsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-stats"]],
    "cifti_in": InputPathType,
    "opt_reduce_operation": typing.NotRequired[str | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[int | None],
    "roi": typing.NotRequired[CiftiStatsRoiParameters | None],
    "opt_show_map_name": bool,
})
CiftiStatsParametersTagged = typing.TypedDict('CiftiStatsParametersTagged', {
    "@type": typing.Literal["workbench/cifti-stats"],
    "cifti_in": InputPathType,
    "opt_reduce_operation": typing.NotRequired[str | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[int | None],
    "roi": typing.NotRequired[CiftiStatsRoiParameters | None],
    "opt_show_map_name": bool,
})


def cifti_stats_roi_params(
    roi_cifti: InputPathType,
    opt_match_maps: bool = False,
) -> CiftiStatsRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_cifti: the roi, as a cifti file.
        opt_match_maps: each column of input uses the corresponding column from\
            the roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi_cifti": roi_cifti,
        "opt_match_maps": opt_match_maps,
    }
    return params


def cifti_stats_roi_cargs(
    params: CiftiStatsRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi")
    cargs.append(execution.input_file(params.get("roi_cifti", None)))
    if params.get("opt_match_maps", False):
        cargs.append("-match-maps")
    return cargs


class CiftiStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiStatsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_stats_params(
    cifti_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_column_column: int | None = None,
    roi: CiftiStatsRoiParameters | None = None,
    opt_show_map_name: bool = False,
) -> CiftiStatsParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_column_column: only display output for one column: the column index\
            (starting from 1).
        roi: only consider data inside an roi.
        opt_show_map_name: print column index and name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-stats",
        "cifti_in": cifti_in,
        "opt_show_map_name": opt_show_map_name,
    }
    if opt_reduce_operation is not None:
        params["opt_reduce_operation"] = opt_reduce_operation
    if opt_percentile_percent is not None:
        params["opt_percentile_percent"] = opt_percentile_percent
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if roi is not None:
        params["roi"] = roi
    return params


def cifti_stats_cargs(
    params: CiftiStatsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-stats")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    if params.get("opt_reduce_operation", None) is not None:
        cargs.extend([
            "-reduce",
            params.get("opt_reduce_operation", None)
        ])
    if params.get("opt_percentile_percent", None) is not None:
        cargs.extend([
            "-percentile",
            str(params.get("opt_percentile_percent", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            str(params.get("opt_column_column", None))
        ])
    if params.get("roi", None) is not None:
        cargs.extend(cifti_stats_roi_cargs(params.get("roi", None), execution))
    if params.get("opt_show_map_name", False):
        cargs.append("-show-map-name")
    return cargs


def cifti_stats_outputs(
    params: CiftiStatsParameters,
    execution: Execution,
) -> CiftiStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiStatsOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_stats_execute(
    params: CiftiStatsParameters,
    runner: Runner | None = None,
) -> CiftiStatsOutputs:
    """
    cifti-stats
    
    Statistics along cifti columns.
    
    For each column of the input, a line of text is printed, resulting from the
    specified reduction or percentile operation. If -roi is specified without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Use -column to only give
    output for a single data column. Exactly one of -reduce or -percentile must
    be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_STATS_METADATA)
    params = execution.params(params)
    cargs = cifti_stats_cargs(params, execution)
    ret = cifti_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_stats(
    cifti_in: InputPathType,
    opt_reduce_operation: str | None = None,
    opt_percentile_percent: float | None = None,
    opt_column_column: int | None = None,
    roi: CiftiStatsRoiParameters | None = None,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> CiftiStatsOutputs:
    """
    cifti-stats
    
    Statistics along cifti columns.
    
    For each column of the input, a line of text is printed, resulting from the
    specified reduction or percentile operation. If -roi is specified without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Use -column to only give
    output for a single data column. Exactly one of -reduce or -percentile must
    be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti.
        opt_reduce_operation: use a reduction operation: the reduction\
            operation.
        opt_percentile_percent: give the value at a percentile: the percentile\
            to find, must be between 0 and 100.
        opt_column_column: only display output for one column: the column index\
            (starting from 1).
        roi: only consider data inside an roi.
        opt_show_map_name: print column index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiStatsOutputs`).
    """
    params = cifti_stats_params(
        cifti_in=cifti_in,
        opt_reduce_operation=opt_reduce_operation,
        opt_percentile_percent=opt_percentile_percent,
        opt_column_column=opt_column_column,
        roi=roi,
        opt_show_map_name=opt_show_map_name,
    )
    return cifti_stats_execute(params, runner)


__all__ = [
    "CIFTI_STATS_METADATA",
    "CiftiStatsOutputs",
    "cifti_stats",
    "cifti_stats_execute",
    "cifti_stats_params",
    "cifti_stats_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_FILE_EXPORT_TO_CARET5_METADATA = Metadata(
    id="5bdb523cf35c997b31a3b9033a83e1125033b032.boutiques",
    name="border-file-export-to-caret5",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderFileExportToCaret5SurfaceParameters = typing.TypedDict('BorderFileExportToCaret5SurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["surface"]],
    "surface_in": InputPathType,
})
BorderFileExportToCaret5SurfaceParametersTagged = typing.TypedDict('BorderFileExportToCaret5SurfaceParametersTagged', {
    "@type": typing.Literal["surface"],
    "surface_in": InputPathType,
})


BorderFileExportToCaret5Parameters = typing.TypedDict('BorderFileExportToCaret5Parameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-file-export-to-caret5"]],
    "border_file": str,
    "output_file_prefix": str,
    "surface": typing.NotRequired[list[BorderFileExportToCaret5SurfaceParameters] | None],
})
BorderFileExportToCaret5ParametersTagged = typing.TypedDict('BorderFileExportToCaret5ParametersTagged', {
    "@type": typing.Literal["workbench/border-file-export-to-caret5"],
    "border_file": str,
    "output_file_prefix": str,
    "surface": typing.NotRequired[list[BorderFileExportToCaret5SurfaceParameters] | None],
})


def border_file_export_to_caret5_surface_params(
    surface_in: InputPathType,
) -> BorderFileExportToCaret5SurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_in: a surface file for unprojection of borders.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface",
        "surface_in": surface_in,
    }
    return params


def border_file_export_to_caret5_surface_cargs(
    params: BorderFileExportToCaret5SurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surface")
    cargs.append(execution.input_file(params.get("surface_in", None)))
    return cargs


class BorderFileExportToCaret5Outputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderFileExportToCaret5Parameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_file_export_to_caret5_params(
    border_file: str,
    output_file_prefix: str,
    surface: list[BorderFileExportToCaret5SurfaceParameters] | None = None,
) -> BorderFileExportToCaret5ParametersTagged:
    """
    Build parameters.
    
    Args:
        border_file: workbench border file.
        output_file_prefix: prefix for name of output caret5\
            border/borderproj/bordercolor files.
        surface: specify an input surface.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-file-export-to-caret5",
        "border_file": border_file,
        "output_file_prefix": output_file_prefix,
    }
    if surface is not None:
        params["surface"] = surface
    return params


def border_file_export_to_caret5_cargs(
    params: BorderFileExportToCaret5Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-file-export-to-caret5")
    cargs.append(params.get("border_file", None))
    cargs.append(params.get("output_file_prefix", None))
    if params.get("surface", None) is not None:
        cargs.extend([a for c in [border_file_export_to_caret5_surface_cargs(s, execution) for s in params.get("surface", None)] for a in c])
    return cargs


def border_file_export_to_caret5_outputs(
    params: BorderFileExportToCaret5Parameters,
    execution: Execution,
) -> BorderFileExportToCaret5Outputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderFileExportToCaret5Outputs(
        root=execution.output_file("."),
    )
    return ret


def border_file_export_to_caret5_execute(
    params: BorderFileExportToCaret5Parameters,
    runner: Runner | None = None,
) -> BorderFileExportToCaret5Outputs:
    """
    border-file-export-to-caret5
    
    Export border file to caret5 file format.
    
    A Workbench border file may contain borders for multiple structures and
    borders that are both projected and unprojected. It also contains a color
    table for the borders.
    
    Caret5 has both border (unprojected) and border projection (projected)
    files. In addition, each Caret5 border or border projection file typically
    contains data for a single structure. Caret5 also uses a border color file
    that associates colors with the names of the borders.
    
    This command will try to output both Caret5 border and border projection
    files. Each output border/border projection file will contains data for one
    structure so there may be many files created. The structure name is included
    in the name of each border or border projection file that is created.
    
    One Caret5 border color file will also be produced by this command.
    
    Providing surface(s) as input parameters is optional, but recommended.
    Surfaces may be needed to create both projected and/or unprojected
    coordinates of borders. If there is a failure to produce an output border or
    border projection due to a missing surface with the matching structure, an
    error message will be displayed and some output files will not be created.
    
    When writing new files, this command will overwrite a file with the same
    name. .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderFileExportToCaret5Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_FILE_EXPORT_TO_CARET5_METADATA)
    params = execution.params(params)
    cargs = border_file_export_to_caret5_cargs(params, execution)
    ret = border_file_export_to_caret5_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_file_export_to_caret5(
    border_file: str,
    output_file_prefix: str,
    surface: list[BorderFileExportToCaret5SurfaceParameters] | None = None,
    runner: Runner | None = None,
) -> BorderFileExportToCaret5Outputs:
    """
    border-file-export-to-caret5
    
    Export border file to caret5 file format.
    
    A Workbench border file may contain borders for multiple structures and
    borders that are both projected and unprojected. It also contains a color
    table for the borders.
    
    Caret5 has both border (unprojected) and border projection (projected)
    files. In addition, each Caret5 border or border projection file typically
    contains data for a single structure. Caret5 also uses a border color file
    that associates colors with the names of the borders.
    
    This command will try to output both Caret5 border and border projection
    files. Each output border/border projection file will contains data for one
    structure so there may be many files created. The structure name is included
    in the name of each border or border projection file that is created.
    
    One Caret5 border color file will also be produced by this command.
    
    Providing surface(s) as input parameters is optional, but recommended.
    Surfaces may be needed to create both projected and/or unprojected
    coordinates of borders. If there is a failure to produce an output border or
    border projection due to a missing surface with the matching structure, an
    error message will be displayed and some output files will not be created.
    
    When writing new files, this command will overwrite a file with the same
    name. .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border_file: workbench border file.
        output_file_prefix: prefix for name of output caret5\
            border/borderproj/bordercolor files.
        surface: specify an input surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderFileExportToCaret5Outputs`).
    """
    params = border_file_export_to_caret5_params(
        border_file=border_file,
        output_file_prefix=output_file_prefix,
        surface=surface,
    )
    return border_file_export_to_caret5_execute(params, runner)


__all__ = [
    "BORDER_FILE_EXPORT_TO_CARET5_METADATA",
    "BorderFileExportToCaret5Outputs",
    "border_file_export_to_caret5",
    "border_file_export_to_caret5_execute",
    "border_file_export_to_caret5_params",
    "border_file_export_to_caret5_surface_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ALL_LABELS_TO_ROIS_METADATA = Metadata(
    id="6faa7bc1774fe5d690eab193fadb4498d97e0945.boutiques",
    name="cifti-all-labels-to-rois",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiAllLabelsToRoisParameters = typing.TypedDict('CiftiAllLabelsToRoisParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-all-labels-to-rois"]],
    "label_in": InputPathType,
    "map": str,
    "cifti_out": str,
})
CiftiAllLabelsToRoisParametersTagged = typing.TypedDict('CiftiAllLabelsToRoisParametersTagged', {
    "@type": typing.Literal["workbench/cifti-all-labels-to-rois"],
    "label_in": InputPathType,
    "map": str,
    "cifti_out": str,
})


class CiftiAllLabelsToRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiAllLabelsToRoisParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_all_labels_to_rois_params(
    label_in: InputPathType,
    map_: str,
    cifti_out: str,
) -> CiftiAllLabelsToRoisParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input cifti label file.
        map_: the number or name of the label map to use.
        cifti_out: the output cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-all-labels-to-rois",
        "label_in": label_in,
        "map": map_,
        "cifti_out": cifti_out,
    }
    return params


def cifti_all_labels_to_rois_cargs(
    params: CiftiAllLabelsToRoisParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-all-labels-to-rois")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("map", None))
    cargs.append(params.get("cifti_out", None))
    return cargs


def cifti_all_labels_to_rois_outputs(
    params: CiftiAllLabelsToRoisParameters,
    execution: Execution,
) -> CiftiAllLabelsToRoisOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiAllLabelsToRoisOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_all_labels_to_rois_execute(
    params: CiftiAllLabelsToRoisParameters,
    runner: Runner | None = None,
) -> CiftiAllLabelsToRoisOutputs:
    """
    cifti-all-labels-to-rois
    
    Make rois from all labels in a cifti label map.
    
    The output cifti file is a dscalar file with a column (map) for each label
    in the specified input map, other than the ??? label, each of which contains
    a binary ROI of all brainordinates that are set to the corresponding label.
    
    Most of the time, specifying '1' for the <map> argument will do what is
    desired.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAllLabelsToRoisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ALL_LABELS_TO_ROIS_METADATA)
    params = execution.params(params)
    cargs = cifti_all_labels_to_rois_cargs(params, execution)
    ret = cifti_all_labels_to_rois_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_all_labels_to_rois(
    label_in: InputPathType,
    map_: str,
    cifti_out: str,
    runner: Runner | None = None,
) -> CiftiAllLabelsToRoisOutputs:
    """
    cifti-all-labels-to-rois
    
    Make rois from all labels in a cifti label map.
    
    The output cifti file is a dscalar file with a column (map) for each label
    in the specified input map, other than the ??? label, each of which contains
    a binary ROI of all brainordinates that are set to the corresponding label.
    
    Most of the time, specifying '1' for the <map> argument will do what is
    desired.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input cifti label file.
        map_: the number or name of the label map to use.
        cifti_out: the output cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAllLabelsToRoisOutputs`).
    """
    params = cifti_all_labels_to_rois_params(
        label_in=label_in,
        map_=map_,
        cifti_out=cifti_out,
    )
    return cifti_all_labels_to_rois_execute(params, runner)


__all__ = [
    "CIFTI_ALL_LABELS_TO_ROIS_METADATA",
    "CiftiAllLabelsToRoisOutputs",
    "cifti_all_labels_to_rois",
    "cifti_all_labels_to_rois_execute",
    "cifti_all_labels_to_rois_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_GRADIENT_METADATA = Metadata(
    id="a8e5c3ed0a78482d9c66120c39db3f77c9a52343.boutiques",
    name="cifti-gradient",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiGradientLeftSurfaceParameters = typing.TypedDict('CiftiGradientLeftSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["left_surface"]],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientLeftSurfaceParametersTagged = typing.TypedDict('CiftiGradientLeftSurfaceParametersTagged', {
    "@type": typing.Literal["left_surface"],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiGradientRightSurfaceParameters = typing.TypedDict('CiftiGradientRightSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["right_surface"]],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientRightSurfaceParametersTagged = typing.TypedDict('CiftiGradientRightSurfaceParametersTagged', {
    "@type": typing.Literal["right_surface"],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiGradientCerebellumSurfaceParameters = typing.TypedDict('CiftiGradientCerebellumSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_surface"]],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientCerebellumSurfaceParametersTagged = typing.TypedDict('CiftiGradientCerebellumSurfaceParametersTagged', {
    "@type": typing.Literal["cerebellum_surface"],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiGradientParameters = typing.TypedDict('CiftiGradientParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-gradient"]],
    "cifti": InputPathType,
    "direction": str,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiGradientLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiGradientRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiGradientCerebellumSurfaceParameters | None],
    "opt_surface_presmooth_surface_kernel": typing.NotRequired[float | None],
    "opt_volume_presmooth_volume_kernel": typing.NotRequired[float | None],
    "opt_presmooth_fwhm": bool,
    "opt_average_output": bool,
    "opt_vectors_vectors_out": typing.NotRequired[str | None],
})
CiftiGradientParametersTagged = typing.TypedDict('CiftiGradientParametersTagged', {
    "@type": typing.Literal["workbench/cifti-gradient"],
    "cifti": InputPathType,
    "direction": str,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiGradientLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiGradientRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiGradientCerebellumSurfaceParameters | None],
    "opt_surface_presmooth_surface_kernel": typing.NotRequired[float | None],
    "opt_volume_presmooth_volume_kernel": typing.NotRequired[float | None],
    "opt_presmooth_fwhm": bool,
    "opt_average_output": bool,
    "opt_vectors_vectors_out": typing.NotRequired[str | None],
})


def cifti_gradient_left_surface_params(
    surface: InputPathType,
    opt_left_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiGradientLeftSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        opt_left_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the left surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_surface",
        "surface": surface,
    }
    if opt_left_corrected_areas_area_metric is not None:
        params["opt_left_corrected_areas_area_metric"] = opt_left_corrected_areas_area_metric
    return params


def cifti_gradient_left_surface_cargs(
    params: CiftiGradientLeftSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_left_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-left-corrected-areas",
            execution.input_file(params.get("opt_left_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_gradient_right_surface_params(
    surface: InputPathType,
    opt_right_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiGradientRightSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        opt_right_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the right surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_surface",
        "surface": surface,
    }
    if opt_right_corrected_areas_area_metric is not None:
        params["opt_right_corrected_areas_area_metric"] = opt_right_corrected_areas_area_metric
    return params


def cifti_gradient_right_surface_cargs(
    params: CiftiGradientRightSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_right_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-right-corrected-areas",
            execution.input_file(params.get("opt_right_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_gradient_cerebellum_surface_params(
    surface: InputPathType,
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiGradientCerebellumSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        opt_cerebellum_corrected_areas_area_metric: vertex areas to use instead\
            of computing them from the cerebellum surface: the corrected vertex\
            areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_surface",
        "surface": surface,
    }
    if opt_cerebellum_corrected_areas_area_metric is not None:
        params["opt_cerebellum_corrected_areas_area_metric"] = opt_cerebellum_corrected_areas_area_metric
    return params


def cifti_gradient_cerebellum_surface_cargs(
    params: CiftiGradientCerebellumSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_cerebellum_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-cerebellum-corrected-areas",
            execution.input_file(params.get("opt_cerebellum_corrected_areas_area_metric", None))
        ])
    return cargs


class CiftiGradientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiGradientParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""
    opt_vectors_vectors_out: OutputPathType | None
    """output gradient vectors: the vectors, as a dscalar file"""


def cifti_gradient_params(
    cifti: InputPathType,
    direction: str,
    cifti_out: str,
    left_surface: CiftiGradientLeftSurfaceParameters | None = None,
    right_surface: CiftiGradientRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiGradientCerebellumSurfaceParameters | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    opt_average_output: bool = False,
    opt_vectors_vectors_out: str | None = None,
) -> CiftiGradientParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti.
        direction: which dimension to take the gradient along, ROW or COLUMN.
        cifti_out: the output cifti.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian surface smoothing\
            kernel in mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian volume smoothing\
            kernel in mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel sizes are FWHM, not sigma.
        opt_average_output: output the average of the gradient magnitude maps\
            instead of each gradient map separately.
        opt_vectors_vectors_out: output gradient vectors: the vectors, as a\
            dscalar file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-gradient",
        "cifti": cifti,
        "direction": direction,
        "cifti_out": cifti_out,
        "opt_presmooth_fwhm": opt_presmooth_fwhm,
        "opt_average_output": opt_average_output,
    }
    if left_surface is not None:
        params["left_surface"] = left_surface
    if right_surface is not None:
        params["right_surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum_surface"] = cerebellum_surface
    if opt_surface_presmooth_surface_kernel is not None:
        params["opt_surface_presmooth_surface_kernel"] = opt_surface_presmooth_surface_kernel
    if opt_volume_presmooth_volume_kernel is not None:
        params["opt_volume_presmooth_volume_kernel"] = opt_volume_presmooth_volume_kernel
    if opt_vectors_vectors_out is not None:
        params["opt_vectors_vectors_out"] = opt_vectors_vectors_out
    return params


def cifti_gradient_cargs(
    params: CiftiGradientParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-gradient")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("left_surface", None) is not None:
        cargs.extend(cifti_gradient_left_surface_cargs(params.get("left_surface", None), execution))
    if params.get("right_surface", None) is not None:
        cargs.extend(cifti_gradient_right_surface_cargs(params.get("right_surface", None), execution))
    if params.get("cerebellum_surface", None) is not None:
        cargs.extend(cifti_gradient_cerebellum_surface_cargs(params.get("cerebellum_surface", None), execution))
    if params.get("opt_surface_presmooth_surface_kernel", None) is not None:
        cargs.extend([
            "-surface-presmooth",
            str(params.get("opt_surface_presmooth_surface_kernel", None))
        ])
    if params.get("opt_volume_presmooth_volume_kernel", None) is not None:
        cargs.extend([
            "-volume-presmooth",
            str(params.get("opt_volume_presmooth_volume_kernel", None))
        ])
    if params.get("opt_presmooth_fwhm", False):
        cargs.append("-presmooth-fwhm")
    if params.get("opt_average_output", False):
        cargs.append("-average-output")
    if params.get("opt_vectors_vectors_out", None) is not None:
        cargs.extend([
            "-vectors",
            params.get("opt_vectors_vectors_out", None)
        ])
    return cargs


def cifti_gradient_outputs(
    params: CiftiGradientParameters,
    execution: Execution,
) -> CiftiGradientOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiGradientOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
        opt_vectors_vectors_out=execution.output_file(params.get("opt_vectors_vectors_out", None)) if (params.get("opt_vectors_vectors_out") is not None) else None,
    )
    return ret


def cifti_gradient_execute(
    params: CiftiGradientParameters,
    runner: Runner | None = None,
) -> CiftiGradientOutputs:
    """
    cifti-gradient
    
    Take gradient of a cifti file.
    
    Performs gradient calculation on each component of the cifti file, and
    optionally averages the resulting gradients. The -vectors and
    -average-output options may not be used together. You must specify a surface
    for each surface structure in the cifti file. The COLUMN direction should be
    faster, and is the direction that works on dtseries. For dconn, you probably
    want ROW, unless you are using -average-output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiGradientOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_GRADIENT_METADATA)
    params = execution.params(params)
    cargs = cifti_gradient_cargs(params, execution)
    ret = cifti_gradient_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_gradient(
    cifti: InputPathType,
    direction: str,
    cifti_out: str,
    left_surface: CiftiGradientLeftSurfaceParameters | None = None,
    right_surface: CiftiGradientRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiGradientCerebellumSurfaceParameters | None = None,
    opt_surface_presmooth_surface_kernel: float | None = None,
    opt_volume_presmooth_volume_kernel: float | None = None,
    opt_presmooth_fwhm: bool = False,
    opt_average_output: bool = False,
    opt_vectors_vectors_out: str | None = None,
    runner: Runner | None = None,
) -> CiftiGradientOutputs:
    """
    cifti-gradient
    
    Take gradient of a cifti file.
    
    Performs gradient calculation on each component of the cifti file, and
    optionally averages the resulting gradients. The -vectors and
    -average-output options may not be used together. You must specify a surface
    for each surface structure in the cifti file. The COLUMN direction should be
    faster, and is the direction that works on dtseries. For dconn, you probably
    want ROW, unless you are using -average-output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti.
        direction: which dimension to take the gradient along, ROW or COLUMN.
        cifti_out: the output cifti.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_surface_presmooth_surface_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian surface smoothing\
            kernel in mm, as sigma by default.
        opt_volume_presmooth_volume_kernel: smooth on the surface before\
            computing the gradient: the size of the gaussian volume smoothing\
            kernel in mm, as sigma by default.
        opt_presmooth_fwhm: smoothing kernel sizes are FWHM, not sigma.
        opt_average_output: output the average of the gradient magnitude maps\
            instead of each gradient map separately.
        opt_vectors_vectors_out: output gradient vectors: the vectors, as a\
            dscalar file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiGradientOutputs`).
    """
    params = cifti_gradient_params(
        cifti=cifti,
        direction=direction,
        cifti_out=cifti_out,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
        opt_surface_presmooth_surface_kernel=opt_surface_presmooth_surface_kernel,
        opt_volume_presmooth_volume_kernel=opt_volume_presmooth_volume_kernel,
        opt_presmooth_fwhm=opt_presmooth_fwhm,
        opt_average_output=opt_average_output,
        opt_vectors_vectors_out=opt_vectors_vectors_out,
    )
    return cifti_gradient_execute(params, runner)


__all__ = [
    "CIFTI_GRADIENT_METADATA",
    "CiftiGradientOutputs",
    "cifti_gradient",
    "cifti_gradient_cerebellum_surface_params",
    "cifti_gradient_execute",
    "cifti_gradient_left_surface_params",
    "cifti_gradient_params",
    "cifti_gradient_right_surface_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

PROBTRACKX_DOT_CONVERT_METADATA = Metadata(
    id="b29597e31e2270ad6df214d52b90ea8e4c08e0d5.boutiques",
    name="probtrackx-dot-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


ProbtrackxDotConvertRowVoxelsParameters = typing.TypedDict('ProbtrackxDotConvertRowVoxelsParameters', {
    "@type": typing.NotRequired[typing.Literal["row_voxels"]],
    "voxel_list_file": str,
    "label_vol": InputPathType,
})
ProbtrackxDotConvertRowVoxelsParametersTagged = typing.TypedDict('ProbtrackxDotConvertRowVoxelsParametersTagged', {
    "@type": typing.Literal["row_voxels"],
    "voxel_list_file": str,
    "label_vol": InputPathType,
})


ProbtrackxDotConvertRowCiftiParameters = typing.TypedDict('ProbtrackxDotConvertRowCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["row_cifti"]],
    "cifti": InputPathType,
    "direction": str,
})
ProbtrackxDotConvertRowCiftiParametersTagged = typing.TypedDict('ProbtrackxDotConvertRowCiftiParametersTagged', {
    "@type": typing.Literal["row_cifti"],
    "cifti": InputPathType,
    "direction": str,
})


ProbtrackxDotConvertColVoxelsParameters = typing.TypedDict('ProbtrackxDotConvertColVoxelsParameters', {
    "@type": typing.NotRequired[typing.Literal["col_voxels"]],
    "voxel_list_file": str,
    "label_vol": InputPathType,
})
ProbtrackxDotConvertColVoxelsParametersTagged = typing.TypedDict('ProbtrackxDotConvertColVoxelsParametersTagged', {
    "@type": typing.Literal["col_voxels"],
    "voxel_list_file": str,
    "label_vol": InputPathType,
})


ProbtrackxDotConvertColCiftiParameters = typing.TypedDict('ProbtrackxDotConvertColCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["col_cifti"]],
    "cifti": InputPathType,
    "direction": str,
})
ProbtrackxDotConvertColCiftiParametersTagged = typing.TypedDict('ProbtrackxDotConvertColCiftiParametersTagged', {
    "@type": typing.Literal["col_cifti"],
    "cifti": InputPathType,
    "direction": str,
})


ProbtrackxDotConvertParameters = typing.TypedDict('ProbtrackxDotConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/probtrackx-dot-convert"]],
    "dot_file": str,
    "cifti_out": str,
    "row_voxels": typing.NotRequired[ProbtrackxDotConvertRowVoxelsParameters | None],
    "opt_row_surface_roi_metric": typing.NotRequired[InputPathType | None],
    "row_cifti": typing.NotRequired[ProbtrackxDotConvertRowCiftiParameters | None],
    "col_voxels": typing.NotRequired[ProbtrackxDotConvertColVoxelsParameters | None],
    "opt_col_surface_roi_metric": typing.NotRequired[InputPathType | None],
    "col_cifti": typing.NotRequired[ProbtrackxDotConvertColCiftiParameters | None],
    "opt_transpose": bool,
    "opt_make_symmetric": bool,
})
ProbtrackxDotConvertParametersTagged = typing.TypedDict('ProbtrackxDotConvertParametersTagged', {
    "@type": typing.Literal["workbench/probtrackx-dot-convert"],
    "dot_file": str,
    "cifti_out": str,
    "row_voxels": typing.NotRequired[ProbtrackxDotConvertRowVoxelsParameters | None],
    "opt_row_surface_roi_metric": typing.NotRequired[InputPathType | None],
    "row_cifti": typing.NotRequired[ProbtrackxDotConvertRowCiftiParameters | None],
    "col_voxels": typing.NotRequired[ProbtrackxDotConvertColVoxelsParameters | None],
    "opt_col_surface_roi_metric": typing.NotRequired[InputPathType | None],
    "col_cifti": typing.NotRequired[ProbtrackxDotConvertColCiftiParameters | None],
    "opt_transpose": bool,
    "opt_make_symmetric": bool,
})


def probtrackx_dot_convert_row_voxels_params(
    voxel_list_file: str,
    label_vol: InputPathType,
) -> ProbtrackxDotConvertRowVoxelsParametersTagged:
    """
    Build parameters.
    
    Args:
        voxel_list_file: a text file containing IJK indices for the voxels used.
        label_vol: a label volume with the dimensions and sform used, with\
            structure labels.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "row_voxels",
        "voxel_list_file": voxel_list_file,
        "label_vol": label_vol,
    }
    return params


def probtrackx_dot_convert_row_voxels_cargs(
    params: ProbtrackxDotConvertRowVoxelsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-row-voxels")
    cargs.append(params.get("voxel_list_file", None))
    cargs.append(execution.input_file(params.get("label_vol", None)))
    return cargs


def probtrackx_dot_convert_row_cifti_params(
    cifti: InputPathType,
    direction: str,
) -> ProbtrackxDotConvertRowCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the cifti file to take the mapping from.
        direction: which dimension to take the mapping along, ROW or COLUMN.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "row_cifti",
        "cifti": cifti,
        "direction": direction,
    }
    return params


def probtrackx_dot_convert_row_cifti_cargs(
    params: ProbtrackxDotConvertRowCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-row-cifti")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("direction", None))
    return cargs


def probtrackx_dot_convert_col_voxels_params(
    voxel_list_file: str,
    label_vol: InputPathType,
) -> ProbtrackxDotConvertColVoxelsParametersTagged:
    """
    Build parameters.
    
    Args:
        voxel_list_file: a text file containing IJK indices for the voxels used.
        label_vol: a label volume with the dimensions and sform used, with\
            structure labels.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "col_voxels",
        "voxel_list_file": voxel_list_file,
        "label_vol": label_vol,
    }
    return params


def probtrackx_dot_convert_col_voxels_cargs(
    params: ProbtrackxDotConvertColVoxelsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-col-voxels")
    cargs.append(params.get("voxel_list_file", None))
    cargs.append(execution.input_file(params.get("label_vol", None)))
    return cargs


def probtrackx_dot_convert_col_cifti_params(
    cifti: InputPathType,
    direction: str,
) -> ProbtrackxDotConvertColCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the cifti file to take the mapping from.
        direction: which dimension to take the mapping along, ROW or COLUMN.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "col_cifti",
        "cifti": cifti,
        "direction": direction,
    }
    return params


def probtrackx_dot_convert_col_cifti_cargs(
    params: ProbtrackxDotConvertColCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-col-cifti")
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("direction", None))
    return cargs


class ProbtrackxDotConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ProbtrackxDotConvertParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def probtrackx_dot_convert_params(
    dot_file: str,
    cifti_out: str,
    row_voxels: ProbtrackxDotConvertRowVoxelsParameters | None = None,
    opt_row_surface_roi_metric: InputPathType | None = None,
    row_cifti: ProbtrackxDotConvertRowCiftiParameters | None = None,
    col_voxels: ProbtrackxDotConvertColVoxelsParameters | None = None,
    opt_col_surface_roi_metric: InputPathType | None = None,
    col_cifti: ProbtrackxDotConvertColCiftiParameters | None = None,
    opt_transpose: bool = False,
    opt_make_symmetric: bool = False,
) -> ProbtrackxDotConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        dot_file: input .dot file.
        cifti_out: output cifti file.
        row_voxels: the output mapping along a row will be voxels.
        opt_row_surface_roi_metric: the output mapping along a row will be\
            surface vertices: a metric file with positive values on all vertices\
            used.
        row_cifti: take the mapping along a row from a cifti file.
        col_voxels: the output mapping along a column will be voxels.
        opt_col_surface_roi_metric: the output mapping along a column will be\
            surface vertices: a metric file with positive values on all vertices\
            used.
        col_cifti: take the mapping along a column from a cifti file.
        opt_transpose: transpose the input matrix.
        opt_make_symmetric: transform half-square input into full matrix output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/probtrackx-dot-convert",
        "dot_file": dot_file,
        "cifti_out": cifti_out,
        "opt_transpose": opt_transpose,
        "opt_make_symmetric": opt_make_symmetric,
    }
    if row_voxels is not None:
        params["row_voxels"] = row_voxels
    if opt_row_surface_roi_metric is not None:
        params["opt_row_surface_roi_metric"] = opt_row_surface_roi_metric
    if row_cifti is not None:
        params["row_cifti"] = row_cifti
    if col_voxels is not None:
        params["col_voxels"] = col_voxels
    if opt_col_surface_roi_metric is not None:
        params["opt_col_surface_roi_metric"] = opt_col_surface_roi_metric
    if col_cifti is not None:
        params["col_cifti"] = col_cifti
    return params


def probtrackx_dot_convert_cargs(
    params: ProbtrackxDotConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-probtrackx-dot-convert")
    cargs.append(params.get("dot_file", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("row_voxels", None) is not None:
        cargs.extend(probtrackx_dot_convert_row_voxels_cargs(params.get("row_voxels", None), execution))
    if params.get("opt_row_surface_roi_metric", None) is not None:
        cargs.extend([
            "-row-surface",
            execution.input_file(params.get("opt_row_surface_roi_metric", None))
        ])
    if params.get("row_cifti", None) is not None:
        cargs.extend(probtrackx_dot_convert_row_cifti_cargs(params.get("row_cifti", None), execution))
    if params.get("col_voxels", None) is not None:
        cargs.extend(probtrackx_dot_convert_col_voxels_cargs(params.get("col_voxels", None), execution))
    if params.get("opt_col_surface_roi_metric", None) is not None:
        cargs.extend([
            "-col-surface",
            execution.input_file(params.get("opt_col_surface_roi_metric", None))
        ])
    if params.get("col_cifti", None) is not None:
        cargs.extend(probtrackx_dot_convert_col_cifti_cargs(params.get("col_cifti", None), execution))
    if params.get("opt_transpose", False):
        cargs.append("-transpose")
    if params.get("opt_make_symmetric", False):
        cargs.append("-make-symmetric")
    return cargs


def probtrackx_dot_convert_outputs(
    params: ProbtrackxDotConvertParameters,
    execution: Execution,
) -> ProbtrackxDotConvertOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ProbtrackxDotConvertOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def probtrackx_dot_convert_execute(
    params: ProbtrackxDotConvertParameters,
    runner: Runner | None = None,
) -> ProbtrackxDotConvertOutputs:
    """
    probtrackx-dot-convert
    
    Convert a .dot file from probtrackx to cifti.
    
    NOTE: exactly one -row option and one -col option must be used.
    
    If the input file does not have its indexes sorted in the correct ordering,
    this command may take longer than expected. Specifying -transpose will
    transpose the input matrix before trying to put its values into the cifti
    file, which is currently needed for at least matrix2 in order to display it
    as intended. How the cifti file is displayed is based on which -row option
    is specified: if -row-voxels is specified, then it will display data on
    volume slices. The label names in the label volume(s) must have the
    following names, other names are ignored:
    
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ProbtrackxDotConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PROBTRACKX_DOT_CONVERT_METADATA)
    params = execution.params(params)
    cargs = probtrackx_dot_convert_cargs(params, execution)
    ret = probtrackx_dot_convert_outputs(params, execution)
    execution.run(cargs)
    return ret


def probtrackx_dot_convert(
    dot_file: str,
    cifti_out: str,
    row_voxels: ProbtrackxDotConvertRowVoxelsParameters | None = None,
    opt_row_surface_roi_metric: InputPathType | None = None,
    row_cifti: ProbtrackxDotConvertRowCiftiParameters | None = None,
    col_voxels: ProbtrackxDotConvertColVoxelsParameters | None = None,
    opt_col_surface_roi_metric: InputPathType | None = None,
    col_cifti: ProbtrackxDotConvertColCiftiParameters | None = None,
    opt_transpose: bool = False,
    opt_make_symmetric: bool = False,
    runner: Runner | None = None,
) -> ProbtrackxDotConvertOutputs:
    """
    probtrackx-dot-convert
    
    Convert a .dot file from probtrackx to cifti.
    
    NOTE: exactly one -row option and one -col option must be used.
    
    If the input file does not have its indexes sorted in the correct ordering,
    this command may take longer than expected. Specifying -transpose will
    transpose the input matrix before trying to put its values into the cifti
    file, which is currently needed for at least matrix2 in order to display it
    as intended. How the cifti file is displayed is based on which -row option
    is specified: if -row-voxels is specified, then it will display data on
    volume slices. The label names in the label volume(s) must have the
    following names, other names are ignored:
    
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        dot_file: input .dot file.
        cifti_out: output cifti file.
        row_voxels: the output mapping along a row will be voxels.
        opt_row_surface_roi_metric: the output mapping along a row will be\
            surface vertices: a metric file with positive values on all vertices\
            used.
        row_cifti: take the mapping along a row from a cifti file.
        col_voxels: the output mapping along a column will be voxels.
        opt_col_surface_roi_metric: the output mapping along a column will be\
            surface vertices: a metric file with positive values on all vertices\
            used.
        col_cifti: take the mapping along a column from a cifti file.
        opt_transpose: transpose the input matrix.
        opt_make_symmetric: transform half-square input into full matrix output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ProbtrackxDotConvertOutputs`).
    """
    params = probtrackx_dot_convert_params(
        dot_file=dot_file,
        cifti_out=cifti_out,
        row_voxels=row_voxels,
        opt_row_surface_roi_metric=opt_row_surface_roi_metric,
        row_cifti=row_cifti,
        col_voxels=col_voxels,
        opt_col_surface_roi_metric=opt_col_surface_roi_metric,
        col_cifti=col_cifti,
        opt_transpose=opt_transpose,
        opt_make_symmetric=opt_make_symmetric,
    )
    return probtrackx_dot_convert_execute(params, runner)


__all__ = [
    "PROBTRACKX_DOT_CONVERT_METADATA",
    "ProbtrackxDotConvertOutputs",
    "probtrackx_dot_convert",
    "probtrackx_dot_convert_col_cifti_params",
    "probtrackx_dot_convert_col_voxels_params",
    "probtrackx_dot_convert_execute",
    "probtrackx_dot_convert_params",
    "probtrackx_dot_convert_row_cifti_params",
    "probtrackx_dot_convert_row_voxels_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FOCI_LIST_COORDS_METADATA = Metadata(
    id="d001c0626bd77c599fb298b784da2e1f848d9719.boutiques",
    name="foci-list-coords",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FociListCoordsParameters = typing.TypedDict('FociListCoordsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/foci-list-coords"]],
    "foci_file": InputPathType,
    "coord_file_out": str,
    "opt_names_out_names_file_out": typing.NotRequired[str | None],
})
FociListCoordsParametersTagged = typing.TypedDict('FociListCoordsParametersTagged', {
    "@type": typing.Literal["workbench/foci-list-coords"],
    "foci_file": InputPathType,
    "coord_file_out": str,
    "opt_names_out_names_file_out": typing.NotRequired[str | None],
})


class FociListCoordsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FociListCoordsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def foci_list_coords_params(
    foci_file: InputPathType,
    coord_file_out: str,
    opt_names_out_names_file_out: str | None = None,
) -> FociListCoordsParametersTagged:
    """
    Build parameters.
    
    Args:
        foci_file: input foci file.
        coord_file_out: output - the output coordinate text file.
        opt_names_out_names_file_out: output the foci names: output - text file\
            to put foci names in.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/foci-list-coords",
        "foci_file": foci_file,
        "coord_file_out": coord_file_out,
    }
    if opt_names_out_names_file_out is not None:
        params["opt_names_out_names_file_out"] = opt_names_out_names_file_out
    return params


def foci_list_coords_cargs(
    params: FociListCoordsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-list-coords")
    cargs.append(execution.input_file(params.get("foci_file", None)))
    cargs.append(params.get("coord_file_out", None))
    if params.get("opt_names_out_names_file_out", None) is not None:
        cargs.extend([
            "-names-out",
            params.get("opt_names_out_names_file_out", None)
        ])
    return cargs


def foci_list_coords_outputs(
    params: FociListCoordsParameters,
    execution: Execution,
) -> FociListCoordsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FociListCoordsOutputs(
        root=execution.output_file("."),
    )
    return ret


def foci_list_coords_execute(
    params: FociListCoordsParameters,
    runner: Runner | None = None,
) -> FociListCoordsOutputs:
    """
    foci-list-coords
    
    Output foci coordinates in a text file.
    
    Output the coordinates for every focus in the foci file, and optionally the
    focus names in a second text file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociListCoordsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_LIST_COORDS_METADATA)
    params = execution.params(params)
    cargs = foci_list_coords_cargs(params, execution)
    ret = foci_list_coords_outputs(params, execution)
    execution.run(cargs)
    return ret


def foci_list_coords(
    foci_file: InputPathType,
    coord_file_out: str,
    opt_names_out_names_file_out: str | None = None,
    runner: Runner | None = None,
) -> FociListCoordsOutputs:
    """
    foci-list-coords
    
    Output foci coordinates in a text file.
    
    Output the coordinates for every focus in the foci file, and optionally the
    focus names in a second text file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        foci_file: input foci file.
        coord_file_out: output - the output coordinate text file.
        opt_names_out_names_file_out: output the foci names: output - text file\
            to put foci names in.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociListCoordsOutputs`).
    """
    params = foci_list_coords_params(
        foci_file=foci_file,
        coord_file_out=coord_file_out,
        opt_names_out_names_file_out=opt_names_out_names_file_out,
    )
    return foci_list_coords_execute(params, runner)


__all__ = [
    "FOCI_LIST_COORDS_METADATA",
    "FociListCoordsOutputs",
    "foci_list_coords",
    "foci_list_coords_execute",
    "foci_list_coords_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ERODE_METADATA = Metadata(
    id="756c3e2f29cb4888d04e3fae1ffa11428dc3f2a0.boutiques",
    name="cifti-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiErodeLeftSurfaceParameters = typing.TypedDict('CiftiErodeLeftSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["left_surface"]],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeLeftSurfaceParametersTagged = typing.TypedDict('CiftiErodeLeftSurfaceParametersTagged', {
    "@type": typing.Literal["left_surface"],
    "surface": InputPathType,
    "opt_left_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiErodeRightSurfaceParameters = typing.TypedDict('CiftiErodeRightSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["right_surface"]],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeRightSurfaceParametersTagged = typing.TypedDict('CiftiErodeRightSurfaceParametersTagged', {
    "@type": typing.Literal["right_surface"],
    "surface": InputPathType,
    "opt_right_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiErodeCerebellumSurfaceParameters = typing.TypedDict('CiftiErodeCerebellumSurfaceParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_surface"]],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeCerebellumSurfaceParametersTagged = typing.TypedDict('CiftiErodeCerebellumSurfaceParametersTagged', {
    "@type": typing.Literal["cerebellum_surface"],
    "surface": InputPathType,
    "opt_cerebellum_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


CiftiErodeParameters = typing.TypedDict('CiftiErodeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-erode"]],
    "cifti_in": InputPathType,
    "direction": str,
    "surface_distance": float,
    "volume_distance": float,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiErodeLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiErodeRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiErodeCerebellumSurfaceParameters | None],
    "opt_merged_volume": bool,
})
CiftiErodeParametersTagged = typing.TypedDict('CiftiErodeParametersTagged', {
    "@type": typing.Literal["workbench/cifti-erode"],
    "cifti_in": InputPathType,
    "direction": str,
    "surface_distance": float,
    "volume_distance": float,
    "cifti_out": str,
    "left_surface": typing.NotRequired[CiftiErodeLeftSurfaceParameters | None],
    "right_surface": typing.NotRequired[CiftiErodeRightSurfaceParameters | None],
    "cerebellum_surface": typing.NotRequired[CiftiErodeCerebellumSurfaceParameters | None],
    "opt_merged_volume": bool,
})


def cifti_erode_left_surface_params(
    surface: InputPathType,
    opt_left_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiErodeLeftSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        opt_left_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the left surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_surface",
        "surface": surface,
    }
    if opt_left_corrected_areas_area_metric is not None:
        params["opt_left_corrected_areas_area_metric"] = opt_left_corrected_areas_area_metric
    return params


def cifti_erode_left_surface_cargs(
    params: CiftiErodeLeftSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_left_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-left-corrected-areas",
            execution.input_file(params.get("opt_left_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_erode_right_surface_params(
    surface: InputPathType,
    opt_right_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiErodeRightSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        opt_right_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the right surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_surface",
        "surface": surface,
    }
    if opt_right_corrected_areas_area_metric is not None:
        params["opt_right_corrected_areas_area_metric"] = opt_right_corrected_areas_area_metric
    return params


def cifti_erode_right_surface_cargs(
    params: CiftiErodeRightSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_right_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-right-corrected-areas",
            execution.input_file(params.get("opt_right_corrected_areas_area_metric", None))
        ])
    return cargs


def cifti_erode_cerebellum_surface_params(
    surface: InputPathType,
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None,
) -> CiftiErodeCerebellumSurfaceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        opt_cerebellum_corrected_areas_area_metric: vertex areas to use instead\
            of computing them from the cerebellum surface: the corrected vertex\
            areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_surface",
        "surface": surface,
    }
    if opt_cerebellum_corrected_areas_area_metric is not None:
        params["opt_cerebellum_corrected_areas_area_metric"] = opt_cerebellum_corrected_areas_area_metric
    return params


def cifti_erode_cerebellum_surface_cargs(
    params: CiftiErodeCerebellumSurfaceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-surface")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_cerebellum_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-cerebellum-corrected-areas",
            execution.input_file(params.get("opt_cerebellum_corrected_areas_area_metric", None))
        ])
    return cargs


class CiftiErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiErodeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_erode_params(
    cifti_in: InputPathType,
    direction: str,
    surface_distance: float,
    volume_distance: float,
    cifti_out: str,
    left_surface: CiftiErodeLeftSurfaceParameters | None = None,
    right_surface: CiftiErodeRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiErodeCerebellumSurfaceParameters | None = None,
    opt_merged_volume: bool = False,
) -> CiftiErodeParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        direction: which dimension to dilate along, ROW or COLUMN.
        surface_distance: the distance to dilate on surfaces, in mm.
        volume_distance: the distance to dilate in the volume, in mm.
        cifti_out: the output cifti file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_merged_volume: treat volume components as if they were a single\
            component.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-erode",
        "cifti_in": cifti_in,
        "direction": direction,
        "surface_distance": surface_distance,
        "volume_distance": volume_distance,
        "cifti_out": cifti_out,
        "opt_merged_volume": opt_merged_volume,
    }
    if left_surface is not None:
        params["left_surface"] = left_surface
    if right_surface is not None:
        params["right_surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum_surface"] = cerebellum_surface
    return params


def cifti_erode_cargs(
    params: CiftiErodeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-erode")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("direction", None))
    cargs.append(str(params.get("surface_distance", None)))
    cargs.append(str(params.get("volume_distance", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("left_surface", None) is not None:
        cargs.extend(cifti_erode_left_surface_cargs(params.get("left_surface", None), execution))
    if params.get("right_surface", None) is not None:
        cargs.extend(cifti_erode_right_surface_cargs(params.get("right_surface", None), execution))
    if params.get("cerebellum_surface", None) is not None:
        cargs.extend(cifti_erode_cerebellum_surface_cargs(params.get("cerebellum_surface", None), execution))
    if params.get("opt_merged_volume", False):
        cargs.append("-merged-volume")
    return cargs


def cifti_erode_outputs(
    params: CiftiErodeParameters,
    execution: Execution,
) -> CiftiErodeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiErodeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_erode_execute(
    params: CiftiErodeParameters,
    runner: Runner | None = None,
) -> CiftiErodeOutputs:
    """
    cifti-erode
    
    Erode a cifti file.
    
    For all data values that are empty (for label data, unlabeled, for other
    data, zero), set the surrounding values to empty. The surrounding values are
    defined as the immediate neighbors and all values in the same structure
    within the specified distance (-merged-volume treats all voxels as one
    structure).
    
    The -*-corrected-areas options are intended for eroding on group average
    surfaces, but it is only an approximate correction.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ERODE_METADATA)
    params = execution.params(params)
    cargs = cifti_erode_cargs(params, execution)
    ret = cifti_erode_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_erode(
    cifti_in: InputPathType,
    direction: str,
    surface_distance: float,
    volume_distance: float,
    cifti_out: str,
    left_surface: CiftiErodeLeftSurfaceParameters | None = None,
    right_surface: CiftiErodeRightSurfaceParameters | None = None,
    cerebellum_surface: CiftiErodeCerebellumSurfaceParameters | None = None,
    opt_merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiErodeOutputs:
    """
    cifti-erode
    
    Erode a cifti file.
    
    For all data values that are empty (for label data, unlabeled, for other
    data, zero), set the surrounding values to empty. The surrounding values are
    defined as the immediate neighbors and all values in the same structure
    within the specified distance (-merged-volume treats all voxels as one
    structure).
    
    The -*-corrected-areas options are intended for eroding on group average
    surfaces, but it is only an approximate correction.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti file.
        direction: which dimension to dilate along, ROW or COLUMN.
        surface_distance: the distance to dilate on surfaces, in mm.
        volume_distance: the distance to dilate in the volume, in mm.
        cifti_out: the output cifti file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiErodeOutputs`).
    """
    params = cifti_erode_params(
        cifti_in=cifti_in,
        direction=direction,
        surface_distance=surface_distance,
        volume_distance=volume_distance,
        cifti_out=cifti_out,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
        opt_merged_volume=opt_merged_volume,
    )
    return cifti_erode_execute(params, runner)


__all__ = [
    "CIFTI_ERODE_METADATA",
    "CiftiErodeOutputs",
    "cifti_erode",
    "cifti_erode_cerebellum_surface_params",
    "cifti_erode_execute",
    "cifti_erode_left_surface_params",
    "cifti_erode_params",
    "cifti_erode_right_surface_params",
]
